MODULE trcstp
   !!======================================================================
   !!                       ***  MODULE trcstp  ***
   !! Time-stepping    : time loop of opa for passive tracer
   !!======================================================================
#if defined key_passivetrc
   !!----------------------------------------------------------------------
   !!   trc_stp      : passive tracer system time-stepping
   !!----------------------------------------------------------------------
   !! * Modules used
   USE oce_trc          ! ocean dynamics and active tracers variables
   USE trc              ! ocean passive tracers variables 
   USE trctrp           ! passive tracers transport
   USE trcsms           ! passive tracers sources and sinks
   USE trcdia          ! passive tracer diagnostics        (trc_dia routine)
   USE trcrst          ! restart for passive tracers

   IMPLICIT NONE
   PRIVATE

   !! * Routine accessibility
   PUBLIC trc_stp           ! called by step
   !!----------------------------------------------------------------------
   !!  TOP 1.0,  LOCEAN-IPSL (2005) 
   !! $Header$ 
   !! This software is governed by the CeCILL licence see modipsl/doc/NEMO_CeCILL.txt 
   !!----------------------------------------------------------------------

CONTAINS

   SUBROUTINE trc_stp( kt )
      !!-------------------------------------------------------------------
      !!                     ***  ROUTINE trc_stp  ***
      !!                      
      !! ** Purpose : Time loop of opa for passive tracer
      !! 
      !! ** Method  : 
      !!              Compute the passive tracers trends 
      !!              Update the passive tracers
      !!
      !! History :
      !!   9.0  !  04-03  (C. Ethe)  Original
      !!-------------------------------------------------------------------
      !! * Arguments
      INTEGER, INTENT( in ) ::  kt  ! ocean time-step index
      INTEGER :: jn
      REAL(wp) :: ztra

      !! * local declarations
      INTEGER ::   indic    ! error indicator if < 0
      !! ---------------------------------------------------------------------

      indic = 1                    ! reset to no error condition



      ! diagnostics init

      IF( kt == nit000 )   CALL trc_dia( kt, indic )

      ! these ROUTINES are called only every ndttrc time step
      IF( MOD( kt , ndttrc ) == 0 ) THEN

         ! tracers: sink and source 

         CALL trc_sms( kt )

         DO jn = 1, jptra
            IF(ln_ctl) THEN         ! print mean trends (used for debugging)
               ztra = SUM( tra(2:nictle,2:njctle,1:jpkm1,jn) * tmask(2:nictle,2:njctle,1:jpkm1) )
               WRITE(numout,*) ' trc/sms  - ',ctrcnm(jn),' : ', ztra-tra_ctl(jn)
               tra_ctl(jn) = ztra
            ENDIF
         END DO

 

         ! transport of passive tracers

         CALL trc_trp( kt )

         DO jn = 1, jptra
            IF(ln_ctl) THEN         ! print mean trends (used for debugging)
               ztra = SUM( tra(2:nictle,2:njctle,1:jpkm1,jn) * tmask(2:nictle,2:njctle,1:jpkm1) )
               WRITE(numout,*) ' trc/trp  - ',ctrcnm(jn),' : ', ztra-tra_ctl(jn)
               tra_ctl(jn) = ztra
            ENDIF
         END DO

      ENDIF

      

      ! outputs

      CALL trc_wri( kt ) 



      ! diagnostics
 
      CALL trc_dia( kt, indic )



   END SUBROUTINE trc_stp

#else
   !!----------------------------------------------------------------------
   !!   Default key                                     NO passive tracers
   !!----------------------------------------------------------------------
CONTAINS
   SUBROUTINE trc_stp( kt )        ! Empty routine
      INTEGER, INTENT(in) :: kt
      WRITE(*,*) 'trc_stp: You should not have seen this print! error?', kt
   END SUBROUTINE trc_stp
#endif

   !!======================================================================
END MODULE trcstp
